## 大宗交易

接口：block_trade

描述：大宗交易

限量：单次最大1000条，总量不限制

积分：300积分可调取，每分钟内限制次数，超过5000积分频次相对较高，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | TS代码（股票代码和日期至少输入一个参数） |
| trade_date | str | N | 交易日期（格式：YYYYMMDD，下同） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS代码 |
| trade_date | str | Y | 交易日历 |
| price | float | Y | 成交价 |
| vol | float | Y | 成交量（万股） |
| amount | float | Y | 成交金额 |
| buyer | str | Y | 买方营业部 |
| seller | str | Y | 卖方营业部 |

接口使用

```python
pro = ts.pro_api()

df = pro.block_trade(trade_date='20181227')
```

数据示例

```python
ts_code   trade_date  price      vol     amount  \
0   600436.SH   20181227  86.95     9.49     825.16   
```